Make a new (generic) trial design
adagraph_design.RdMake a new (generic) trial design
Arguments
- correlation
Correlation matrix describing the structure of the correlations between the different hypotheses, use NA for uncorrelated
- weights
List of weights, measuring how important each hypothesis is
- alpha
Single number, measuring what total alpha should be spent on the FWER
- test_m
Transition matrix describing the graph for the closed test procedure to test the hypotheses
- names
optional names for the hypotheses
Examples
design <- adagraph_design(
correlation=rbind(H1=c(1, NA),
H2=c(NA, 1)),
weights=c(2/3, 1/3),
alpha=0.05,
test_m=rbind(c(0, 1),
c(1, 0)))
design
#> A Adagraph Design object, for testing 2 hypotheses at FWER 0.05.
#>
#> ── No interim test has been performed yet. ─────────────────────────────────────
#> ── No adaptions have been performed yet ────────────────────────────────────────
#> ── No final test has been performed yet ────────────────────────────────────────